@@ -6,7 +6,7 @@ from email.policy import default
 
 # --- general methods ---------------------------------------------------------
 
-def compose(from_mail: str, dest_mail: object, from_name: str = None, dest_name: object = None, text: str = '', text_type: str = 'plain', subject: str = '', blocking: boolean = False):
+def compose(from_mail: str, dest_mail: object, from_name: str = None, dest_name: object = None, text: str = '', text_type: str = 'plain', subject: str = '', blocking: bool = False):
 	message = EmailMessage(policy=default)
 	message['From'] = Address(from_name, from_mail)
 	message['To'] = Address(dest_name, dest_mail)
